@@ -29,7 +29,6 @@
 #include <tiledb/tiledb_serialization.h> // C
 #endif
 
-#include "../external/string_view.hpp"
 #include "../external/tsl/robin_map.h"
 
 #if !defined(NDEBUG)
@@ -721,7 +720,7 @@ public:
     py::object init_pyqc = cond.attr("init_query_condition");
 
     try {
-      attrs_ = init_pyqc(pyschema_, attrs_).cast<std::vector<std::string>>();
+      init_pyqc(pyschema_, attrs_);
     } catch (tiledb::TileDBError &e) {
       TPY_ERROR_LOC(e.what());
     } catch (py::error_already_set &e) {
@@ -1087,6 +1086,11 @@ public:
       py::gil_scoped_release release;
       query_->submit();
     }
+
+    if (query_->query_status() == Query::Status::UNINITIALIZED) {
+      TPY_ERROR_LOC("Unexpected state: Query::Submit returned uninitialized");
+    }
+
     update_read_elem_num();
 
     return;
@@ -1215,6 +1219,10 @@ public:
       query_->submit();
     }
 
+    if (query_->query_status() == Query::Status::UNINITIALIZED) {
+      TPY_ERROR_LOC("Unexpected state: Query::Submit returned uninitialized");
+    }
+
     if (g_stats) {
       auto now = std::chrono::high_resolution_clock::now();
       g_stats.get()->counters["py.core_read_query_initial_submit_time"] +=
@@ -1322,8 +1330,8 @@ public:
           if (!deduplicate_) {
             o = py::str(data_ptr, size);
           } else {
-            auto v = nonstd::string_view{data_ptr, size};
-            auto h = std::hash<nonstd::string_view>()(v);
+            auto v = std::string_view{data_ptr, size};
+            auto h = std::hash<std::string_view>()(v);
             auto needle = map.find(h);
             if (needle == map.end()) {
               o = py::str(data_ptr, size);
@@ -1362,14 +1370,18 @@ public:
   void submit_write() {}
 
   void submit() {
-    if (array_->query_type() == TILEDB_READ)
+    if (array_->query_type() == TILEDB_READ) {
       submit_read();
-    else if (array_->query_type() == TILEDB_WRITE)
+    } else if (array_->query_type() == TILEDB_WRITE) {
       submit_write();
-    else if (array_->query_type() == TILEDB_DELETE)
+    } else if (array_->query_type() == TILEDB_DELETE) {
       query_->submit();
-    else
+      if (query_->query_status() == Query::Status::UNINITIALIZED) {
+        TPY_ERROR_LOC("Unexpected state: Query::Submit returned uninitialized");
+      }
+    } else {
       TPY_ERROR_LOC("Unknown query type!")
+    }
   }
 
   py::dict results() {
