@@ -1,5 +1,4 @@
 import io
-import numpy as np
 from typing import List, overload, Sequence, TYPE_CHECKING, Union
 
 import tiledb.cc as lt
@@ -14,7 +13,6 @@ class Filter(lt.Filter):
 
     def __init__(self, type: lt.FilterOption, ctx: "Ctx" = None):
         self._ctx = ctx or default_ctx()
-
         super().__init__(self._ctx, type)
 
     def __repr__(self) -> str:
@@ -622,6 +620,128 @@ class XORFilter(Filter):
         return {}
 
 
+class WebpFilter(Filter):
+    """
+    The WebP filter provides three options: quality, format, and lossless
+
+    The quality option is used as quality_factor setting for WebP lossy
+    compression and expects a float value in the range of 0.0f - 100.0f
+    Quality of 0 corresponds to low quality and small output sizes, whereas 100
+    is the highest quality and largest output size.
+
+    The format option is used to define colorspace format of image data and
+    expects an enum of TILEDB_WEBP_RGB, TILEDB_WEBP_BGR, TILEDB_WEBP_RGBA, or
+    TILEDB_WEBP_BGRA.
+
+    The lossless option is used to enable(1) or disable(0) lossless compression.
+    With this option enabled, the quality setting will be ignored.
+
+    On write this filter takes raw colorspace values (RGB, RBGA, etc) and encodes
+    into WebP format before writing data to the array.
+
+    On read, this filter decodes WebP data and returns raw colorspace values to
+    the caller.
+
+    This filter expects the array to provide two dimensions for Y, X pixel
+    position. Dimensions may be defined with any name, but Y, X should be at
+    dimension index 0, 1 respectively.
+
+    :param quality: quality_factor setting for lossy WebP compression
+    :type quality: float in range [0.0, 100.0]
+    :param input_format: The input colorspace format of the image
+    :type input_format: np.uint8 corresponding to one of TILEDB_WEBP_{RGB, BGR, RGBA, BGRA}
+    :param lossless: Enable (1) or disable (0) lossless image compression
+    :type lossless: np.uint8
+    :param ctx: A TileDB Context
+    :type ctx: tiledb.Ctx
+
+    **Example:**
+
+    >>> import tiledb, numpy as np, tempfile
+    >>> with tempfile.TemporaryDirectory() as tmp:
+    ...     # Using RGB colorspace format
+    ...     pixel_depth = 3  # For RGBA / BGRA pixel_depth is 4
+    ...     dims = (tiledb.Dim(name='Y',
+    ...                    domain=(1, img_height),
+    ...                    dtype=np.uint8,
+    ...                    tile=img_height / 2,),
+    ...             tiledb.Dim(name='X',
+    ...                    domain=(1, img_width * pixel_depth),
+    ...                    dtype=np.uint8,
+    ...                    tile=(img_width / 2) * pixel_depth,))
+    ...     dom = tiledb.Domain(*dims)
+    ...     rgb = tiledb.Attr(name="rgb", dtype=np.uint8,
+    ...                      filters=tiledb.FilterList([tiledb.WebpFilter(input_format=1, quality=100.0, lossless=1)]))
+    ...     schema = tiledb.ArraySchema(domain=dom, attrs=(rgb,))
+    ...     tiledb.DenseArray.create(tmp + "/array", schema)
+
+    """
+
+    def __init__(
+        self,
+        input_format: int = None,
+        quality: float = None,
+        lossless: bool = None,
+        ctx: "Ctx" = None,
+    ):
+        self._input_format = input_format
+        self._quality = quality
+        self._lossless = lossless
+        self._ctx = ctx or default_ctx()
+
+        super().__init__(lt.FilterType.WEBP, self._ctx)
+
+        if input_format is not None:
+            self._set_option(
+                lt.Context(self._ctx.__capsule__(), False),
+                lt.FilterOption.WEBP_INPUT_FORMAT,
+                input_format,
+            )
+
+        if quality is not None:
+            self._set_option(
+                lt.Context(self._ctx.__capsule__(), False),
+                lt.FilterOption.WEBP_QUALITY,
+                float(quality),
+            )
+
+        if lossless is not None:
+            self._set_option(
+                lt.Context(self._ctx.__capsule__(), False),
+                lt.FilterOption.WEBP_LOSSLESS,
+                lossless,
+            )
+
+    def _attrs_(self):
+        return {
+            "input_format": self._input_format,
+            "quality": self._quality,
+            "lossless": self._lossless,
+        }
+
+    @property
+    def input_format(self):
+        return self._get_option(
+            lt.Context(self._ctx.__capsule__(), False),
+            lt.FilterOption.WEBP_INPUT_FORMAT,
+        )
+
+    @property
+    def quality(self):
+        return self._get_option(
+            lt.Context(self._ctx.__capsule__(), False),
+            lt.FilterOption.WEBP_QUALITY,
+        )
+
+    @property
+    def lossless(self):
+        return self._get_option(
+            lt.Context(self._ctx.__capsule__(), False),
+            lt.FilterOption.WEBP_LOSSLESS,
+        )
+
+
+#
 class FilterList(lt.FilterList):
     """
     An ordered list of Filter objects for filtering TileDB data.
@@ -669,6 +789,7 @@ class FilterList(lt.FilterList):
         lt.FilterType.DICTIONARY: DictionaryFilter,
         lt.FilterType.SCALE_FLOAT: FloatScaleFilter,
         lt.FilterType.XOR: XORFilter,
+        lt.FilterType.WEBP: WebpFilter,
         lt.FilterType.NONE: NoOpFilter,
     }
 
@@ -677,16 +798,20 @@ class FilterList(lt.FilterList):
         filters: Sequence[Filter] = None,
         chunksize: int = None,
         ctx: "Ctx" = None,
-        is_capsule: bool = False,
+        _lt_obj=None,
+        _capsule=None,
     ):
         self._ctx = ctx or default_ctx()
-        _cctx = self._ctx
 
-        if is_capsule:
-            super().__init__(_cctx, filters)
+        if _capsule is not None:
+            super().__init__(self._ctx, _capsule)
+        elif _lt_obj is not None:
+            super().__init__(self._ctx)
+            for i in range(_lt_obj._nfilters()):
+                self._add_filter(_lt_obj._filter(i))
+            chunksize = _lt_obj._chunksize
         else:
-            super().__init__(_cctx)
-
+            super().__init__(self._ctx)
             if filters is not None:
                 filters = list(filters)
                 for f in filters:
