@@ -107,26 +107,30 @@ class QueryConditionTest(DiskTestCase):
 
     def test_unsigned_sparse(self):
         with tiledb.open(self.create_input_array_UIDSA(sparse=True)) as A:
-            with pytest.raises(DeprecationWarning) as exc_info:
-                result = A.query(cond=tiledb.QueryCondition("U < 5"), attrs=["U"])[:]
-                assert all(result["U"] < 5)
+            with pytest.raises(tiledb.TileDBError) as exc_info:
+                A.query(cond=tiledb.QueryCondition("U < 5"), attrs=["U"])[:]
             assert (
-                "Passing `tiledb.QueryCondition` to `cond` is no longer required"
+                "Passing `tiledb.QueryCondition` to `cond` is no longer supported"
                 in str(exc_info.value)
             )
 
+            result = A.query(cond="U < 5", attrs=["U"])[:]
+            assert all(result["U"] < 5)
+
     def test_unsigned_dense(self):
         with tiledb.open(self.create_input_array_UIDSA(sparse=False)) as A:
             mask = A.attr("U").fill
 
-            with pytest.raises(DeprecationWarning) as exc_info:
-                result = A.query(cond=tiledb.QueryCondition("U < 5"), attrs=["U"])[:]
-                assert all(self.filter_dense(result["U"], mask) < 5)
+            with pytest.raises(tiledb.TileDBError) as exc_info:
+                A.query(cond=tiledb.QueryCondition("U < 5"), attrs=["U"])[:]
             assert (
-                "Passing `tiledb.QueryCondition` to `cond` is no longer required"
+                "Passing `tiledb.QueryCondition` to `cond` is no longer supported"
                 in str(exc_info.value)
             )
 
+            result = A.query(cond="U < 5", attrs=["U"])[:]
+            assert all(self.filter_dense(result["U"], mask) < 5)
+
     def test_signed_sparse(self):
         uri = self.create_input_array_UIDSA(sparse=True)
 
@@ -622,21 +626,21 @@ class QueryConditionTest(DiskTestCase):
                 A.query(cond=qc, attr_cond=qc)
             assert "Both `attr_cond` and `cond` were passed." in str(exc_info.value)
 
-            with pytest.raises(DeprecationWarning) as exc_info:
+            with pytest.raises(tiledb.TileDBError) as exc_info:
                 A.query(attr_cond=qc)
-            assert "`attr_cond` is now deprecated" in str(exc_info.value)
+            assert "`attr_cond` is no longer supported" in str(exc_info.value)
 
-            with pytest.raises(DeprecationWarning) as exc_info:
+            with pytest.raises(tiledb.TileDBError) as exc_info:
                 A.query(cond=qc).attr_cond
-            assert "`attr_cond` is now deprecated" in str(exc_info.value)
+            assert "`attr_cond` is no longer supported" in str(exc_info.value)
 
             with pytest.raises(tiledb.TileDBError) as exc_info:
                 A.subarray(1, cond=qc, attr_cond=qc)
             assert "Both `attr_cond` and `cond` were passed." in str(exc_info.value)
 
-            with pytest.raises(DeprecationWarning) as exc_info:
+            with pytest.raises(tiledb.TileDBError) as exc_info:
                 A.subarray(1, attr_cond=qc)
-            assert "`attr_cond` is now deprecated" in str(exc_info.value)
+            assert "`attr_cond` is no longer supported" in str(exc_info.value)
 
     def test_on_dense_dimensions(self):
         with tiledb.open(self.create_input_array_UIDSA(sparse=False)) as A:
@@ -704,6 +708,88 @@ class QueryConditionTest(DiskTestCase):
             # ensures that ' a' does not match 'a'
             assert len(result["A"]) == 0
 
+    @pytest.mark.skipif(not has_pandas(), reason="pandas not installed")
+    def test_do_not_return_attrs(self):
+        with tiledb.open(self.create_input_array_UIDSA(sparse=True)) as A:
+            cond = None
+            assert "D" in A.query(cond=cond, attrs=None)[:]
+            assert "D" not in A.query(cond=cond, attrs=[])[:]
+            assert "D" in A.query(cond=cond, attrs=None).df[:]
+            assert "D" not in A.query(cond=cond, attrs=[]).df[:]
+            assert "D" in A.query(cond=cond, attrs=None).multi_index[:]
+            assert "D" not in A.query(cond=cond, attrs=[]).multi_index[:]
+
+            cond = "D > 100"
+            assert "D" in A.query(cond=cond, attrs=None)[:]
+            assert "D" not in A.query(cond=cond, attrs=[])[:]
+            assert "D" in A.query(cond=cond, attrs=None).df[:]
+            assert "D" not in A.query(cond=cond, attrs=[]).df[:]
+            assert "D" in A.query(cond=cond, attrs=None).multi_index[:]
+            assert "D" not in A.query(cond=cond, attrs=[]).multi_index[:]
+
+    def test_boolean_sparse(self):
+        path = self.path("test_boolean_sparse")
+
+        dom = tiledb.Domain(tiledb.Dim(domain=(1, 10), tile=1, dtype=np.uint32))
+        attrs = [
+            tiledb.Attr(name="a", dtype=np.bool_),
+            tiledb.Attr(name="b", dtype=np.bool_),
+            tiledb.Attr(name="c", dtype=np.bool_),
+        ]
+        schema = tiledb.ArraySchema(domain=dom, attrs=attrs, sparse=True)
+        tiledb.Array.create(path, schema)
+
+        with tiledb.open(path, "w") as arr:
+            arr[np.arange(1, 11)] = {
+                "a": np.random.randint(0, high=2, size=10),
+                "b": np.random.randint(0, high=2, size=10),
+                "c": np.random.randint(0, high=2, size=10),
+            }
+
+        with tiledb.open(path) as A:
+            result = A.query(cond="a == True")[:]
+            assert all(result["a"])
+
+            result = A.query(cond="a == False")[:]
+            assert all(~result["a"])
+
+            result = A.query(cond="a == True and b == True")[:]
+            assert all(result["a"])
+            assert all(result["b"])
+
+            result = A.query(cond="a == False and c == True")[:]
+            assert all(~result["a"])
+            assert all(result["c"])
+
+    def test_boolean_dense(self):
+        path = self.path("test_boolean_dense")
+
+        dom = tiledb.Domain(tiledb.Dim(domain=(1, 10), tile=1, dtype=np.uint32))
+        attrs = [
+            tiledb.Attr(name="a", dtype=np.bool_),
+            tiledb.Attr(name="b", dtype=np.bool_),
+            tiledb.Attr(name="c", dtype=np.bool_),
+        ]
+        schema = tiledb.ArraySchema(domain=dom, attrs=attrs, sparse=False)
+        tiledb.Array.create(path, schema)
+
+        with tiledb.open(path, "w") as arr:
+            arr[:] = {
+                "a": np.random.randint(0, high=2, size=10),
+                "b": np.random.randint(0, high=2, size=10),
+                "c": np.random.randint(0, high=2, size=10),
+            }
+
+        with tiledb.open(path) as A:
+            mask = A.attr("a").fill
+
+            result = A.query(cond="a == True")[:]
+            assert all(self.filter_dense(result["a"], mask))
+
+            result = A.query(cond="a == True and b == True")[:]
+            assert all(self.filter_dense(result["a"], mask))
+            assert all(self.filter_dense(result["b"], mask))
+
 
 class QueryDeleteTest(DiskTestCase):
     def test_basic_sparse(self):
@@ -839,3 +925,31 @@ class QueryDeleteTest(DiskTestCase):
         with tiledb.open(path, "r") as A:
             assert A.nonempty_domain() == ((2, 3),)
             assert_array_equal([2, 3], A[:]["ints"])
+
+    def test_delete_with_string_dimension(self):
+        path = self.path("test_delete_with_string_dimension")
+
+        schema = tiledb.ArraySchema(
+            domain=tiledb.Domain(tiledb.Dim(name="d", dtype="|S0", var=True)),
+            attrs=[tiledb.Attr(name="a", dtype="uint32")],
+            sparse=True,
+        )
+
+        tiledb.Array.create(path, schema)
+
+        with tiledb.open(path, "w") as A:
+            A[["a", "b", "c"]] = [10, 20, 30]
+
+        with tiledb.open(path, "d") as A:
+            A.query(cond="a == 20").submit()
+
+        with tiledb.open(path, "r") as A:
+            assert_array_equal(A[:]["d"], [b"a", b"c"])
+            assert_array_equal(A[:]["a"], [10, 30])
+
+        with tiledb.open(path, "d") as A:
+            A.query(cond="d == 'a'").submit()
+
+        with tiledb.open(path, "r") as A:
+            assert_array_equal(A[:]["d"], [b"c"])
+            assert_array_equal(A[:]["a"], [30])
